@@ -37,6 +37,13 @@ class SelectionAttribute extends Attribute {
 		$this->selection[$value] = $description;
 	}
 
+	public function addValue($new_val,$i=-1) {
+		if (DEBUG_ENABLED && (($fargs=func_get_args())||$fargs='NOARGS'))
+			debug_log('Entered (%%)',5,0,__FILE__,__LINE__,__METHOD__,$fargs);
+
+		$this->addOption($new_val,$i);
+	}
+
 	public function getOptionCount() {
 		return count($this->selection);
 	}
